supports_self_chat property

bool? get supports_self_chat

Generate By General Universe Script Dont edit by hand or anything manual

Implementation

bool? get supports_self_chat {
  try {
    if (rawData["supports_self_chat"] is bool == false) {
      return null;
    }
    return rawData["supports_self_chat"] as bool;
  } catch (e) {
    return null;
  }
}
set supports_self_chat (bool? value)

Generate By General Universe Script Dont edit by hand or anything manual

Implementation

set supports_self_chat(bool? value) {
  rawData["supports_self_chat"] = value;
}