ChatAction class

Generate By Azka Axelion Gibran Aka AZKADEV Script Dont edit by hand or anything manual

Inheritance

Constructors

ChatAction(Map rawData)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Properties

chat_action_cancel ChatActionCancel
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_choosing_contact ChatActionChoosingContact
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_choosing_location ChatActionChoosingLocation
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_choosing_sticker ChatActionChoosingSticker
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_recording_video ChatActionRecordingVideo
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_recording_video_note ChatActionRecordingVideoNote
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_recording_voice_note ChatActionRecordingVoiceNote
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_start_playing_game ChatActionStartPlayingGame
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_typing ChatActionTyping
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_uploading_document ChatActionUploadingDocument
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_uploading_photo ChatActionUploadingPhoto
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_uploading_video ChatActionUploadingVideo
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_uploading_video_note ChatActionUploadingVideoNote
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_uploading_voice_note ChatActionUploadingVoiceNote
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
chat_action_watching_animations ChatActionWatchingAnimations
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setterinherited
rawData Map
return original data json
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
special_is_json_scheme_class bool?
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
special_return_type String?
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
special_type String?
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair

Methods

cast<R>() → R
convert to other
inherited
castOrNull<R>() → R?
convert to other
inherited
json_scheme_utils_checkDataIsSameBuilder({required bool onResult(Map rawData, Map defaultData)}) bool
check value data whatever do yout want
json_scheme_utils_checkDataIsSameBySpecialType() bool
check data if raw data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
return original data json
inherited
toMap() Map
return original data json
inherited
toString() String
return string data encode json original data
inherited
toStringPretty() String
return string data encode json original data
inherited
utils_filter_by_keys(List keys) Map
return original data json
inherited
utils_remove_by_keys(List keys) Map
return original data json
inherited
utils_remove_by_keys_void(List keys) → void
GeneralUniverse
inherited
utils_remove_by_values(List values) Map
return original data json
inherited
utils_remove_by_values_void(List values) → void
return original data json
inherited
utils_remove_values_null() Map
return original data json
inherited
utils_remove_values_null_void() → void
return original data json
inherited

Operators

operator *(dynamic value) → void
operator map data
inherited
operator +(dynamic value) Map
operator map data
inherited
operator -(dynamic value) Map
return original data json
inherited
operator /(dynamic value) → void
operator map data
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
operator map data
inherited
operator []=(dynamic key, dynamic value) → void
operator map data
inherited

Static Properties

defaultData Map
return default data
no setter
defaultDataSpecialType String
return default special type @type "chatAction"
no setter

Static Methods

create({bool schemeUtilsIsSetDefaultData = false, String special_type = "chatAction", bool special_is_json_scheme_class = true, String special_return_type = "chatAction", ChatActionTyping? chat_action_typing, ChatActionRecordingVideo? chat_action_recording_video, ChatActionUploadingVideo? chat_action_uploading_video, ChatActionRecordingVoiceNote? chat_action_recording_voice_note, ChatActionUploadingVoiceNote? chat_action_uploading_voice_note, ChatActionUploadingPhoto? chat_action_uploading_photo, ChatActionUploadingDocument? chat_action_uploading_document, ChatActionChoosingSticker? chat_action_choosing_sticker, ChatActionChoosingLocation? chat_action_choosing_location, ChatActionChoosingContact? chat_action_choosing_contact, ChatActionStartPlayingGame? chat_action_start_playing_game, ChatActionRecordingVideoNote? chat_action_recording_video_note, ChatActionUploadingVideoNote? chat_action_uploading_video_note, ChatActionWatchingAnimations? chat_action_watching_animations, ChatActionCancel? chat_action_cancel}) ChatAction
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
override
empty() ChatAction
create ChatAction Empty
override