ChatStatisticsSupergroup class
Generate By Azka Axelion Gibran Aka AZKADEV Script Dont edit by hand or anything manual
- Inheritance
-
- Object
- JsonSchemeByAzkadev
- ChatStatisticsSupergroup
Constructors
- ChatStatisticsSupergroup(Map rawData)
- Generate By General Universe Script Dont edit by hand or anything manual
Properties
- action_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- day_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
- join_by_source_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- join_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- language_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- member_count ↔ StatisticalValue
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- member_count_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- message_content_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- message_count ↔ StatisticalValue
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- period ↔ DateRange
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- rawData ↔ Map
-
return original data json
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender_count ↔ StatisticalValue
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- special_return_type ↔ String?
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- special_type ↔ String?
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
-
top_administrators
↔ List<
ChatStatisticsAdministratorActionsInfo> -
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
-
top_inviters
↔ List<
ChatStatisticsInviterInfo> -
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
-
top_senders
↔ List<
ChatStatisticsMessageSenderInfo> -
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- viewer_count ↔ StatisticalValue
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
- week_graph ↔ StatisticalGraph
-
Generate By General Universe Script Dont edit by hand or anything manual
getter/setter pair
Methods
-
cast<
R> () → R -
convert to other
inherited
-
castOrNull<
R> () → R? -
convert to other
inherited
-
json_scheme_utils_checkDataIsSameBuilder(
{required bool onResult(Map rawData, Map defaultData)}) → bool - check value data whatever do yout want
-
json_scheme_utils_checkDataIsSameBySpecialType(
) → bool - check data if raw data
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
return original data json
inherited
-
toMap(
) → Map -
return original data json
inherited
-
toString(
) → String -
return string data encode json original data
inherited
-
toStringPretty(
) → String -
return string data encode json original data
inherited
-
utils_filter_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys_void(
List keys) → void -
GeneralUniverse
inherited
-
utils_remove_by_values(
List values) → Map -
return original data json
inherited
-
utils_remove_by_values_void(
List values) → void -
return original data json
inherited
-
utils_remove_values_null(
) → Map -
return original data json
inherited
-
utils_remove_values_null_void(
) → void -
return original data json
inherited
Operators
-
operator *(
dynamic value) → void -
operator map data
inherited
-
operator +(
dynamic value) → Map -
operator map data
inherited
-
operator -(
dynamic value) → Map -
return original data json
inherited
-
operator /(
dynamic value) → void -
operator map data
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic key) → dynamic -
operator map data
inherited
-
operator []=(
dynamic key, dynamic value) → void -
operator map data
inherited
Static Properties
- defaultData → Map
-
return default data
no setter
- defaultDataSpecialType → String
-
return default special type @type
"chatStatisticsSupergroup"
no setter
Static Methods
-
create(
{bool schemeUtilsIsSetDefaultData = false, String special_type = "chatStatisticsSupergroup", String special_return_type = "chatStatistics", DateRange? period, StatisticalValue? member_count, StatisticalValue? message_count, StatisticalValue? viewer_count, StatisticalValue? sender_count, StatisticalGraph? member_count_graph, StatisticalGraph? join_graph, StatisticalGraph? join_by_source_graph, StatisticalGraph? language_graph, StatisticalGraph? message_content_graph, StatisticalGraph? action_graph, StatisticalGraph? day_graph, StatisticalGraph? week_graph, List< ChatStatisticsMessageSenderInfo> ? top_senders, List<ChatStatisticsAdministratorActionsInfo> ? top_administrators, List<ChatStatisticsInviterInfo> ? top_inviters}) → ChatStatisticsSupergroup -
Generate By General Universe Script Dont edit by hand or anything manual
override
-
empty(
) → ChatStatisticsSupergroup -
create ChatStatisticsSupergroup
Empty
override