translation property

List<DatedFile> get translation

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

List<DatedFile> get translation {
  try {
    if (rawData["translation"] is List == false) {
      return [];
    }
    return (rawData["translation"] as List).map((e) => DatedFile(e as Map)).toList().cast<DatedFile>();
  } catch (e) {
    return [];
  }
}
set translation (List<DatedFile> values)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set translation(List<DatedFile> values) {
  rawData["translation"] = values.map((value) => value.toJson()).toList();
}