photo_height property
num?
get
photo_height
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
num? get photo_height {
try {
if (rawData["photo_height"] is num == false) {
return null;
}
return rawData["photo_height"] as num;
} catch (e) {
return null;
}
}
set
photo_height
(num? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set photo_height(num? value) {
rawData["photo_height"] = value;
}