photo property
InputFile
get
photo
Generate By General Universe Script Dont edit by hand or anything manual
Implementation
InputFile get photo {
try {
if (rawData["photo"] is Map == false) {
return InputFile({});
}
return InputFile(rawData["photo"] as Map);
} catch (e) {
return InputFile({});
}
}
set
photo
(InputFile value)
Generate By General Universe Script Dont edit by hand or anything manual
Implementation
set photo(InputFile value) {
rawData["photo"] = value.toJson();
}