added_sticker_file_ids property

List<num> get added_sticker_file_ids

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

default:

Implementation

List<num> get added_sticker_file_ids {
  try {
    if (rawData["added_sticker_file_ids"] is List == false) {
      return [];
    }
    return (rawData["added_sticker_file_ids"] as List).cast<num>();
  } catch (e) {
    return [];
  }
}
set added_sticker_file_ids (List<num> value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set added_sticker_file_ids(List<num> value) {
  rawData["added_sticker_file_ids"] = value;
}