is_flexible property
bool?
get
is_flexible
Generate By General Universe Script Dont edit by hand or anything manual
Implementation
bool? get is_flexible {
try {
if (rawData["is_flexible"] is bool == false) {
return null;
}
return rawData["is_flexible"] as bool;
} catch (e) {
return null;
}
}
set
is_flexible
(bool? value)
Generate By General Universe Script Dont edit by hand or anything manual
Implementation
set is_flexible(bool? value) {
rawData["is_flexible"] = value;
}