is_downloading_active property

bool? get is_downloading_active

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

bool? get is_downloading_active {
  try {
    if (rawData["is_downloading_active"] is bool == false) {
      return null;
    }
    return rawData["is_downloading_active"] as bool;
  } catch (e) {
    return null;
  }
}
set is_downloading_active (bool? value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set is_downloading_active(bool? value) {
  rawData["is_downloading_active"] = value;
}