is_downloading_completed property
bool?
get
is_downloading_completed
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
bool? get is_downloading_completed {
try {
if (rawData["is_downloading_completed"] is bool == false) {
return null;
}
return rawData["is_downloading_completed"] as bool;
} catch (e) {
return null;
}
}
set
is_downloading_completed
(bool? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set is_downloading_completed(bool? value) {
rawData["is_downloading_completed"] = value;
}