mask_point_forehead property

MaskPointForehead get mask_point_forehead

Generate By General Universe Script Dont edit by hand or anything manual

Implementation

MaskPointForehead get mask_point_forehead {
  try {
    if (rawData["mask_point_forehead"] is Map == false) {
      return MaskPointForehead({});
    }
    return MaskPointForehead(rawData["mask_point_forehead"] as Map);
  } catch (e) {
    return MaskPointForehead({});
  }
}
set mask_point_forehead (MaskPointForehead value)

Generate By General Universe Script Dont edit by hand or anything manual

Implementation

set mask_point_forehead(MaskPointForehead value) {
  rawData["mask_point_forehead"] = value.toJson();
}