is_channel_post property
bool?
get
is_channel_post
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
bool? get is_channel_post {
try {
if (rawData["is_channel_post"] is bool == false) {
return null;
}
return rawData["is_channel_post"] as bool;
} catch (e) {
return null;
}
}
set
is_channel_post
(bool? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set is_channel_post(bool? value) {
rawData["is_channel_post"] = value;
}