need_shipping_address property
bool?
get
need_shipping_address
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
bool? get need_shipping_address {
try {
if (rawData["need_shipping_address"] is bool == false) {
return null;
}
return rawData["need_shipping_address"] as bool;
} catch (e) {
return null;
}
}
set
need_shipping_address
(bool? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set need_shipping_address(bool? value) {
rawData["need_shipping_address"] = value;
}