sender_chat_id property
num?
get
sender_chat_id
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
num? get sender_chat_id {
try {
if (rawData["sender_chat_id"] is num == false) {
return null;
}
return rawData["sender_chat_id"] as num;
} catch (e) {
return null;
}
}
set
sender_chat_id
(num? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set sender_chat_id(num? value) {
rawData["sender_chat_id"] = value;
}