can_report_reactions property
bool?
get
can_report_reactions
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
bool? get can_report_reactions {
try {
if (rawData["can_report_reactions"] is bool == false) {
return null;
}
return rawData["can_report_reactions"] as bool;
} catch (e) {
return null;
}
}
set
can_report_reactions
(bool? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set can_report_reactions(bool? value) {
rawData["can_report_reactions"] = value;
}