is_striped property

bool? get is_striped

Generate By General Universe Script Dont edit by hand or anything manual

Implementation

bool? get is_striped {
  try {
    if (rawData["is_striped"] is bool == false) {
      return null;
    }
    return rawData["is_striped"] as bool;
  } catch (e) {
    return null;
  }
}
set is_striped (bool? value)

Generate By General Universe Script Dont edit by hand or anything manual

Implementation

set is_striped(bool? value) {
  rawData["is_striped"] = value;
}