ReceivedGift class
Generate By Azka Axelion Gibran Aka AZKADEV Script Dont edit by hand or anything manual
- Inheritance
-
- Object
- JsonSchemeByAzkadev
- ReceivedGift
Constructors
- ReceivedGift(Map rawData)
- Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Properties
- can_be_transferred ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- can_be_upgraded ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- date ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- export_date ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- gift ↔ SentGift
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- is_pinned ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- is_private ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- is_saved ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
- prepaid_upgrade_star_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- rawData ↔ Map
-
return original data json
getter/setter pairinherited
- received_gift_id ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sell_star_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- sender_id ↔ MessageSender
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- special_return_type ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- special_type ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- text ↔ FormattedText
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- transfer_star_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- was_refunded ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
Methods
-
cast<
R> () → R -
convert to other
inherited
-
castOrNull<
R> () → R? -
convert to other
inherited
-
json_scheme_utils_checkDataIsSameBuilder(
{required bool onResult(Map rawData, Map defaultData)}) → bool - check value data whatever do yout want
-
json_scheme_utils_checkDataIsSameBySpecialType(
) → bool - check data if raw data
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
return original data json
inherited
-
toMap(
) → Map -
return original data json
inherited
-
toString(
) → String -
return string data encode json original data
inherited
-
toStringPretty(
) → String -
return string data encode json original data
inherited
-
utils_filter_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys_void(
List keys) → void -
GeneralUniverse
inherited
-
utils_remove_by_values(
List values) → Map -
return original data json
inherited
-
utils_remove_by_values_void(
List values) → void -
return original data json
inherited
-
utils_remove_values_null(
) → Map -
return original data json
inherited
-
utils_remove_values_null_void(
) → void -
return original data json
inherited
Operators
-
operator *(
dynamic value) → void -
operator map data
inherited
-
operator +(
dynamic value) → Map -
operator map data
inherited
-
operator -(
dynamic value) → Map -
return original data json
inherited
-
operator /(
dynamic value) → void -
operator map data
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic key) → dynamic -
operator map data
inherited
-
operator []=(
dynamic key, dynamic value) → void -
operator map data
inherited
Static Properties
- defaultData → Map
-
return default data
no setter
- defaultDataSpecialType → String
-
return default special type @type
"receivedGift"
no setter
Static Methods
-
create(
{bool schemeUtilsIsSetDefaultData = false, String special_type = "receivedGift", String special_return_type = "receivedGift", String? received_gift_id, MessageSender? sender_id, FormattedText? text, bool? is_private, bool? is_saved, bool? is_pinned, bool? can_be_upgraded, bool? can_be_transferred, bool? was_refunded, num? date, SentGift? gift, num? sell_star_count, num? prepaid_upgrade_star_count, num? transfer_star_count, num? export_date}) → ReceivedGift -
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
override
-
empty(
) → ReceivedGift -
create ReceivedGift
Empty
override