new_sticker property

InputSticker get new_sticker

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

InputSticker get new_sticker {
  try {
    if (rawData["new_sticker"] is Map == false) {
      return InputSticker({});
    }
    return InputSticker(rawData["new_sticker"] as Map);
  } catch (e) {
    return InputSticker({});
  }
}
set new_sticker (InputSticker value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set new_sticker(InputSticker value) {
  rawData["new_sticker"] = value.toJson();
}