can_accept_secret_chats property

bool? get can_accept_secret_chats

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

bool? get can_accept_secret_chats {
  try {
    if (rawData["can_accept_secret_chats"] is bool == false) {
      return null;
    }
    return rawData["can_accept_secret_chats"] as bool;
  } catch (e) {
    return null;
  }
}
set can_accept_secret_chats (bool? value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set can_accept_secret_chats(bool? value) {
  rawData["can_accept_secret_chats"] = value;
}