SuggestedAction class

Generate By Azka Axelion Gibran Aka AZKADEV Script Dont edit by hand or anything manual

Inheritance

Constructors

SuggestedAction(Map rawData)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setterinherited
rawData Map
return original data json
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
special_is_json_scheme_class bool?
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
special_return_type String?
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
special_type String?
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_check_password SuggestedActionCheckPassword
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_check_phone_number SuggestedActionCheckPhoneNumber
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_convert_to_broadcast_group SuggestedActionConvertToBroadcastGroup
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_enable_archive_and_mute_new_chats SuggestedActionEnableArchiveAndMuteNewChats
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_extend_premium SuggestedActionExtendPremium
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_extend_star_subscriptions SuggestedActionExtendStarSubscriptions
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_gift_premium_for_christmas SuggestedActionGiftPremiumForChristmas
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_restore_premium SuggestedActionRestorePremium
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_set_birthdate SuggestedActionSetBirthdate
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_set_password SuggestedActionSetPassword
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_set_profile_photo SuggestedActionSetProfilePhoto
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_subscribe_to_annual_premium SuggestedActionSubscribeToAnnualPremium
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_upgrade_premium SuggestedActionUpgradePremium
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
suggested_action_view_checks_hint SuggestedActionViewChecksHint
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair

Methods

cast<R>() → R
convert to other
inherited
castOrNull<R>() → R?
convert to other
inherited
json_scheme_utils_checkDataIsSameBuilder({required bool onResult(Map rawData, Map defaultData)}) bool
check value data whatever do yout want
json_scheme_utils_checkDataIsSameBySpecialType() bool
check data if raw data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
return original data json
inherited
toMap() Map
return original data json
inherited
toString() String
return string data encode json original data
inherited
toStringPretty() String
return string data encode json original data
inherited
utils_filter_by_keys(List keys) Map
return original data json
inherited
utils_remove_by_keys(List keys) Map
return original data json
inherited
utils_remove_by_keys_void(List keys) → void
GeneralUniverse
inherited
utils_remove_by_values(List values) Map
return original data json
inherited
utils_remove_by_values_void(List values) → void
return original data json
inherited
utils_remove_values_null() Map
return original data json
inherited
utils_remove_values_null_void() → void
return original data json
inherited

Operators

operator *(dynamic value) → void
operator map data
inherited
operator +(dynamic value) Map
operator map data
inherited
operator -(dynamic value) Map
return original data json
inherited
operator /(dynamic value) → void
operator map data
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
operator map data
inherited
operator []=(dynamic key, dynamic value) → void
operator map data
inherited

Static Properties

defaultData Map
return default data
no setter
defaultDataSpecialType String
return default special type @type "suggestedAction"
no setter

Static Methods

create({bool schemeUtilsIsSetDefaultData = false, String special_type = "suggestedAction", bool special_is_json_scheme_class = true, String special_return_type = "suggestedAction", SuggestedActionEnableArchiveAndMuteNewChats? suggested_action_enable_archive_and_mute_new_chats, SuggestedActionCheckPassword? suggested_action_check_password, SuggestedActionCheckPhoneNumber? suggested_action_check_phone_number, SuggestedActionViewChecksHint? suggested_action_view_checks_hint, SuggestedActionConvertToBroadcastGroup? suggested_action_convert_to_broadcast_group, SuggestedActionSetPassword? suggested_action_set_password, SuggestedActionUpgradePremium? suggested_action_upgrade_premium, SuggestedActionRestorePremium? suggested_action_restore_premium, SuggestedActionSubscribeToAnnualPremium? suggested_action_subscribe_to_annual_premium, SuggestedActionGiftPremiumForChristmas? suggested_action_gift_premium_for_christmas, SuggestedActionSetBirthdate? suggested_action_set_birthdate, SuggestedActionSetProfilePhoto? suggested_action_set_profile_photo, SuggestedActionExtendPremium? suggested_action_extend_premium, SuggestedActionExtendStarSubscriptions? suggested_action_extend_star_subscriptions}) SuggestedAction
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
override
empty() SuggestedAction
create SuggestedAction Empty
override