Supergroup class
Generate By Azka Axelion Gibran Aka AZKADEV Script Dont edit by hand or anything manual
- Inheritance
-
- Object
- JsonSchemeByAzkadev
- Supergroup
Constructors
- Supergroup(Map rawData)
- Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Properties
- boost_level ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- date ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_active_stories ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_linked_chat ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_location ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_sensitive_content ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_unread_active_stories ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- is_broadcast_group ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- is_channel ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- is_forum ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- is_slow_mode_enabled ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
- join_by_request ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- join_to_send_messages ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- member_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- paid_message_star_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- rawData ↔ Map
-
return original data json
getter/setter pairinherited
- restriction_reason ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show_message_sender ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- sign_messages ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- special_return_type ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- special_type ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- status ↔ ChatMemberStatus
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- usernames ↔ Usernames
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- verification_status ↔ VerificationStatus
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
Methods
-
cast<
R> () → R -
convert to other
inherited
-
castOrNull<
R> () → R? -
convert to other
inherited
-
json_scheme_utils_checkDataIsSameBuilder(
{required bool onResult(Map rawData, Map defaultData)}) → bool - check value data whatever do yout want
-
json_scheme_utils_checkDataIsSameBySpecialType(
) → bool - check data if raw data
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
return original data json
inherited
-
toMap(
) → Map -
return original data json
inherited
-
toString(
) → String -
return string data encode json original data
inherited
-
toStringPretty(
) → String -
return string data encode json original data
inherited
-
utils_filter_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys_void(
List keys) → void -
GeneralUniverse
inherited
-
utils_remove_by_values(
List values) → Map -
return original data json
inherited
-
utils_remove_by_values_void(
List values) → void -
return original data json
inherited
-
utils_remove_values_null(
) → Map -
return original data json
inherited
-
utils_remove_values_null_void(
) → void -
return original data json
inherited
Operators
-
operator *(
dynamic value) → void -
operator map data
inherited
-
operator +(
dynamic value) → Map -
operator map data
inherited
-
operator -(
dynamic value) → Map -
return original data json
inherited
-
operator /(
dynamic value) → void -
operator map data
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic key) → dynamic -
operator map data
inherited
-
operator []=(
dynamic key, dynamic value) → void -
operator map data
inherited
Static Properties
- defaultData → Map
-
return default data
no setter
- defaultDataSpecialType → String
-
return default special type @type
"supergroup"
no setter
Static Methods
-
create(
{bool schemeUtilsIsSetDefaultData = false, String special_type = "supergroup", String special_return_type = "supergroup", num? id, Usernames? usernames, num? date, ChatMemberStatus? status, num? member_count, num? boost_level, bool? has_linked_chat, bool? has_location, bool? sign_messages, bool? show_message_sender, bool? join_to_send_messages, bool? join_by_request, bool? is_slow_mode_enabled, bool? is_channel, bool? is_broadcast_group, bool? is_forum, VerificationStatus? verification_status, bool? has_sensitive_content, String? restriction_reason, num? paid_message_star_count, bool? has_active_stories, bool? has_unread_active_stories}) → Supergroup -
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
override
-
empty(
) → Supergroup -
create Supergroup
Empty
override