update_chat_pending_join_requests property

UpdateChatPendingJoinRequests get update_chat_pending_join_requests

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

UpdateChatPendingJoinRequests get update_chat_pending_join_requests {
  try {
    if (rawData["update_chat_pending_join_requests"] is Map == false) {
      return UpdateChatPendingJoinRequests({});
    }
    return UpdateChatPendingJoinRequests(rawData["update_chat_pending_join_requests"] as Map);
  } catch (e) {
    return UpdateChatPendingJoinRequests({});
  }
}
set update_chat_pending_join_requests (UpdateChatPendingJoinRequests value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set update_chat_pending_join_requests(UpdateChatPendingJoinRequests value) {
  rawData["update_chat_pending_join_requests"] = value.toJson();
}