update_chat_read_inbox property

UpdateChatReadInbox get update_chat_read_inbox

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

UpdateChatReadInbox get update_chat_read_inbox {
  try {
    if (rawData["update_chat_read_inbox"] is Map == false) {
      return UpdateChatReadInbox({});
    }
    return UpdateChatReadInbox(rawData["update_chat_read_inbox"] as Map);
  } catch (e) {
    return UpdateChatReadInbox({});
  }
}
set update_chat_read_inbox (UpdateChatReadInbox value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set update_chat_read_inbox(UpdateChatReadInbox value) {
  rawData["update_chat_read_inbox"] = value.toJson();
}