update_saved_notification_sounds property
UpdateSavedNotificationSounds
get
update_saved_notification_sounds
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
UpdateSavedNotificationSounds get update_saved_notification_sounds {
try {
if (rawData["update_saved_notification_sounds"] is Map == false) {
return UpdateSavedNotificationSounds({});
}
return UpdateSavedNotificationSounds(rawData["update_saved_notification_sounds"] as Map);
} catch (e) {
return UpdateSavedNotificationSounds({});
}
}
set
update_saved_notification_sounds
(UpdateSavedNotificationSounds value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set update_saved_notification_sounds(UpdateSavedNotificationSounds value) {
rawData["update_saved_notification_sounds"] = value.toJson();
}