update_story_stealth_mode property
UpdateStoryStealthMode
get
update_story_stealth_mode
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
UpdateStoryStealthMode get update_story_stealth_mode {
try {
if (rawData["update_story_stealth_mode"] is Map == false) {
return UpdateStoryStealthMode({});
}
return UpdateStoryStealthMode(rawData["update_story_stealth_mode"] as Map);
} catch (e) {
return UpdateStoryStealthMode({});
}
}
set
update_story_stealth_mode
(UpdateStoryStealthMode value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set update_story_stealth_mode(UpdateStoryStealthMode value) {
rawData["update_story_stealth_mode"] = value.toJson();
}