restricts_new_chats property

bool? get restricts_new_chats

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

bool? get restricts_new_chats {
  try {
    if (rawData["restricts_new_chats"] is bool == false) {
      return null;
    }
    return rawData["restricts_new_chats"] as bool;
  } catch (e) {
    return null;
  }
}
set restricts_new_chats (bool? value)

Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual

Implementation

set restricts_new_chats(bool? value) {
  rawData["restricts_new_chats"] = value;
}