can_be_reported property
bool?
get
can_be_reported
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
bool? get can_be_reported {
try {
if (rawData["can_be_reported"] is bool == false) {
return null;
}
return rawData["can_be_reported"] as bool;
} catch (e) {
return null;
}
}
set
can_be_reported
(bool? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set can_be_reported(bool? value) {
rawData["can_be_reported"] = value;
}