need_show_statistics property
bool?
get
need_show_statistics
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
bool? get need_show_statistics {
try {
if (rawData["need_show_statistics"] is bool == false) {
return null;
}
return rawData["need_show_statistics"] as bool;
} catch (e) {
return null;
}
}
set
need_show_statistics
(bool? value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set need_show_statistics(bool? value) {
rawData["need_show_statistics"] = value;
}