reply_markup_show_keyboard property
ReplyMarkupShowKeyboard
get
reply_markup_show_keyboard
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
ReplyMarkupShowKeyboard get reply_markup_show_keyboard {
try {
if (rawData["reply_markup_show_keyboard"] is Map == false) {
return ReplyMarkupShowKeyboard({});
}
return ReplyMarkupShowKeyboard(rawData["reply_markup_show_keyboard"] as Map);
} catch (e) {
return ReplyMarkupShowKeyboard({});
}
}
set
reply_markup_show_keyboard
(ReplyMarkupShowKeyboard value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set reply_markup_show_keyboard(ReplyMarkupShowKeyboard value) {
rawData["reply_markup_show_keyboard"] = value.toJson();
}