update_favorite_stickers property
UpdateFavoriteStickers
get
update_favorite_stickers
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
UpdateFavoriteStickers get update_favorite_stickers {
try {
if (rawData["update_favorite_stickers"] is Map == false) {
return UpdateFavoriteStickers({});
}
return UpdateFavoriteStickers(rawData["update_favorite_stickers"] as Map);
} catch (e) {
return UpdateFavoriteStickers({});
}
}
set
update_favorite_stickers
(UpdateFavoriteStickers value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set update_favorite_stickers(UpdateFavoriteStickers value) {
rawData["update_favorite_stickers"] = value.toJson();
}