update_message_live_location_viewed property
UpdateMessageLiveLocationViewed
get
update_message_live_location_viewed
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
UpdateMessageLiveLocationViewed get update_message_live_location_viewed {
try {
if (rawData["update_message_live_location_viewed"] is Map == false) {
return UpdateMessageLiveLocationViewed({});
}
return UpdateMessageLiveLocationViewed(rawData["update_message_live_location_viewed"] as Map);
} catch (e) {
return UpdateMessageLiveLocationViewed({});
}
}
set
update_message_live_location_viewed
(UpdateMessageLiveLocationViewed value)
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Implementation
set update_message_live_location_viewed(UpdateMessageLiveLocationViewed value) {
rawData["update_message_live_location_viewed"] = value.toJson();
}