UserFullInfo class
Generate By Azka Axelion Gibran Aka AZKADEV Script Dont edit by hand or anything manual
- Inheritance
-
- Object
- JsonSchemeByAzkadev
- UserFullInfo
Constructors
- UserFullInfo(Map rawData)
- Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
Properties
- bio ↔ FormattedText
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- birthdate ↔ Birthdate
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- block_list ↔ BlockList
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- bot_info ↔ BotInfo
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- bot_verification ↔ BotVerification
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- business_info ↔ BusinessInfo
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- can_be_called ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- gift_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- group_in_common_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_posted_to_profile_stories ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_private_calls ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_private_forwards ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_restricted_voice_and_video_note_messages ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- has_sponsored_messages_enabled ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- incoming_paid_message_star_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
- need_phone_number_privacy_exception ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- outgoing_paid_message_star_count ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- personal_chat_id ↔ num?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- personal_photo ↔ ChatPhoto
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- photo ↔ ChatPhoto
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- public_photo ↔ ChatPhoto
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- rawData ↔ Map
-
return original data json
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- set_chat_background ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- special_return_type ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- special_type ↔ String?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
- supports_video_calls ↔ bool?
-
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
getter/setter pair
Methods
-
cast<
R> () → R -
convert to other
inherited
-
castOrNull<
R> () → R? -
convert to other
inherited
-
json_scheme_utils_checkDataIsSameBuilder(
{required bool onResult(Map rawData, Map defaultData)}) → bool - check value data whatever do yout want
-
json_scheme_utils_checkDataIsSameBySpecialType(
) → bool - check data if raw data
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
return original data json
inherited
-
toMap(
) → Map -
return original data json
inherited
-
toString(
) → String -
return string data encode json original data
inherited
-
toStringPretty(
) → String -
return string data encode json original data
inherited
-
utils_filter_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys(
List keys) → Map -
return original data json
inherited
-
utils_remove_by_keys_void(
List keys) → void -
GeneralUniverse
inherited
-
utils_remove_by_values(
List values) → Map -
return original data json
inherited
-
utils_remove_by_values_void(
List values) → void -
return original data json
inherited
-
utils_remove_values_null(
) → Map -
return original data json
inherited
-
utils_remove_values_null_void(
) → void -
return original data json
inherited
Operators
-
operator *(
dynamic value) → void -
operator map data
inherited
-
operator +(
dynamic value) → Map -
operator map data
inherited
-
operator -(
dynamic value) → Map -
return original data json
inherited
-
operator /(
dynamic value) → void -
operator map data
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic key) → dynamic -
operator map data
inherited
-
operator []=(
dynamic key, dynamic value) → void -
operator map data
inherited
Static Properties
- defaultData → Map
-
return default data
no setter
- defaultDataSpecialType → String
-
return default special type @type
"userFullInfo"
no setter
Static Methods
-
create(
{bool schemeUtilsIsSetDefaultData = false, String special_type = "userFullInfo", String special_return_type = "userFullInfo", ChatPhoto? personal_photo, ChatPhoto? photo, ChatPhoto? public_photo, BlockList? block_list, bool? can_be_called, bool? supports_video_calls, bool? has_private_calls, bool? has_private_forwards, bool? has_restricted_voice_and_video_note_messages, bool? has_posted_to_profile_stories, bool? has_sponsored_messages_enabled, bool? need_phone_number_privacy_exception, bool? set_chat_background, FormattedText? bio, Birthdate? birthdate, num? personal_chat_id, num? gift_count, num? group_in_common_count, num? incoming_paid_message_star_count, num? outgoing_paid_message_star_count, BotVerification? bot_verification, BusinessInfo? business_info, BotInfo? bot_info}) → UserFullInfo -
Generate By AZKADEV | Azka Axelion Gibran Script Dont edit by hand or anything manual
override
-
empty(
) → UserFullInfo -
create UserFullInfo
Empty
override